#include "maemo5locationprivate.h"
#include <QMessageBox>

/**
  *Default constructor of this class.
  *@param Maemo5Location pointer to public interface.
  */
Maemo5LocationPrivate::Maemo5LocationPrivate(Maemo5Location* location):QObject(location)
{
    //Initialize variables
    latitude = 0;
    longitude = 0;
    usegps = -1;
    //Get gps control object
    control = location_gpsd_control_get_default();
    //create gps device
    device = (LocationGPSDevice*) g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);
    g_signal_connect(device, "changed", G_CALLBACK(gps_data_changed), this);
    g_signal_connect(device, "connected", G_CALLBACK(gps_data_connected), this);
}
/**
  *Destructor of this class. Should be used to release all allocated resources.
  */
Maemo5LocationPrivate::~Maemo5LocationPrivate()
{
}

/**
  *This function is used to start to poll with gprs
  */
void Maemo5LocationPrivate::get_acwp()
{
    g_object_set(G_OBJECT(control), "preferred-method", LOCATION_METHOD_ACWP, NULL);
    usegps = 0;
    restart();
}

/**
  *This function starts to poll via gps interface
  */
void Maemo5LocationPrivate::get_agnss()
{
    g_object_set(G_OBJECT(control), "preferred-method", LOCATION_METHOD_AGNSS, NULL);
    usegps = 1;
    restart();
}

/**
  *Stop pollling
  */
void Maemo5LocationPrivate::stop()
{
    location_gpsd_control_stop(control);
}

/**
  *Stop and restart polling
  */
void Maemo5LocationPrivate::restart()
{
    location_gpsd_control_stop(control);
    location_gpsd_control_start(control);
}

void gps_data_connected(LocationGPSDevice *device, Maemo5LocationPrivate *gps)
{
    emit gps->connected();
}
/**
  *Callback function to catch gps signals
  */
void gps_data_changed(LocationGPSDevice *device, Maemo5LocationPrivate *gps)
{
    //First check that LocationGpsDeviceFix can be found...this data structure contains the location info.
    if(gps->device->fix)
    {
        //Check that there are fields
        if(gps->device->fix->fields)
        {
            //Store values and emit signal
            gps->latitude = gps->device->fix->latitude;
            gps->longitude = gps->device->fix->longitude;
            if(gps->usegps == 0)
            {
                emit gps->awcp();
            }
            else if(gps->usegps == 1)
            {
                emit gps->agnss();
            }
            else
            {
                emit gps->locationUpdated();
            }
        }
    }

}
