/**
* @mainwindow.cpp
* Tähän tekstiä luokan/koodin yleisestä toiminnasta…
* Copyright (c) Ari Iivari 2009
* @version 1.0
*/

#include "mainwindow.h"
//#include "location.cpp"

//#include <Q3VBoxLayout>

struct diaryContent{
    QString eDateTime;
    QString eHeader;
    QString eText;
    QString elat;
    QString elon;
};

diaryContent diaryArray[100];

/**
* Constructor
*
* @param -
* @return -
*/
MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent){

    this->createActions();
    this->createToolBars();
    this->createMenus();
    this->createTextLayout();
    this->createCoordLayout();
    this->createButtons();

    //Päänäkymän layout
    QVBoxLayout* mainLayout = new QVBoxLayout();

    //Nest the layouts
    mainLayout->addLayout(mainGridlayout);
    mainLayout->addLayout(buttonLayout);

    location = new Maemo5Location(this);
    //parser = new xmlParser();
    manager = new diaryDataManager();
    manager->printData();

    this->setCentralWidget(new QWidget());
    this->centralWidget()->setLayout(mainLayout);
}

/**
* MainWindows destructor.
*
* @param -
* @return -
*/
MainWindow::~MainWindow(){
    /*if (xmlparser)
        delete xmlparser;
    */
    if (manager)
        delete manager;
}

/**
* Function create header and content fields
*
* @param -
* @return -
*/
void MainWindow::createTextLayout(){
    mainGridlayout = new QGridLayout();
    dtime = QDateTime::currentDateTime();
    strDate = dtime.toString("dd.MM.yyyy hh:mm");

    textLayout = new QVBoxLayout();
    dateLabel = new QLabel(strDate,this);
    //dateLabel->setText("Now: %s",strDate);
    textLayout->addWidget(dateLabel);
    headerText = new QLineEdit(this);
    headerText->setMaxLength(50);
    textLayout->addWidget(headerText);;
    textContent = new QTextEdit(this);
    textLayout->addWidget(textContent);

    mainGridlayout->addLayout(textLayout,0,0);
}

/**
* Function create layout for coordinate field
*
* @param -
* @return -
*/
void MainWindow::createCoordLayout(){
    latitudeString.setText("65");
    longitudeString.setText("30");
    coordGridLayout = new QGridLayout();
    latCoordLabel = new QLabel("lat:",this);
    lonCoordLabel = new QLabel("lon:",this);;
    latCoordData = new QLineEdit(latitudeString.text());
    latCoordData->setMaximumWidth(250);

    lonCoordData = new QLineEdit(longitudeString.text());
    lonCoordData->setMaximumWidth(250);

    /*
    accLabel = new QLabel("acc:",this);;
    accData = new QLineEdit(QString::number(0));
    accData->setMaximumWidth(250);
    */

    getCoordButton = new QPushButton(tr("Get location"),this);
    getCoordButton->setMaximumWidth(220);

    coordGridLayout->verticalSpacing();
    coordGridLayout->addWidget(latCoordLabel,0,0,1,1,Qt::AlignRight);
    coordGridLayout->addWidget(latCoordData,0,1,1,1,Qt::AlignLeft);
    coordGridLayout->addWidget(lonCoordLabel,1,0,1,1,Qt::AlignRight);
    coordGridLayout->addWidget(lonCoordData,1,1,1,1,Qt::AlignLeft);
    //coordGridLayout->addWidget(accLabel,3,0,1,1,Qt::AlignRight);
    //coordGridLayout->addWidget(accData,3,1,1,1,Qt::AlignLeft);
    coordGridLayout->addWidget(getCoordButton,4,0,20,0,Qt::AlignTop);

    connect(getCoordButton,SIGNAL(clicked()),this,SLOT(getCoordinates()));

    mainGridlayout->addLayout(coordGridLayout,0,1);
}

/**
* Function create buttons
*
* @param -
* @return -
*/
void MainWindow::createButtons(){
    buttonLayout = new QHBoxLayout();
    QString strText[MAX_BUTTONS] = {tr("Save"),
                                    tr("Clear"),
                                    tr("Exit")};

    for(int i = 0; i < MAX_BUTTONS; i++){
        buttons[i] = new QPushButton(strText[i],this);
        buttonLayout->addWidget(buttons[i]);
    }

//    connect(buttons[OPEN],SIGNAL(clicked()),this,SLOT(openApplication()));
    connect(buttons[CLEAR],SIGNAL(clicked()),this,SLOT(clearTextFields()));
    connect(buttons[EXIT],SIGNAL(clicked()),this,SLOT(close()));
    connect(buttons[SAVE],SIGNAL(clicked()),this,SLOT(saveData()));
}

/**
* Function clear all text fields
*
* @param -
* @return -
*/
void MainWindow::clearTextFields(){
    headerText->setText("");
    textContent->setText("");

}

/**
* Function get coordinates from GPS
*
* @param -
* @return -
*/
void MainWindow::getCoordinates(){
    //connect(location, SIGNAL(agnss()), this, SLOT(getCoordinates()));
    latitudeString.setText(QString::number(location->getLatitude()));
    longitudeString.setText(QString::number(location->getLongitude()));
    //latitudeString = "3434458";
    //longitudeString = "7384738";
    latCoordData->setText(latitudeString.text());
    lonCoordData->setText(longitudeString.text());
}


/**
* Function create actions
*
* @param -
* @return -
*/
void MainWindow::createActions(){
    exitAction = new QAction(tr("E&xit"),this);
    aboutAction = new QAction(tr("&About"),this);
    clearAction = new QAction(tr("&Clear"),this);
    saveAction = new QAction(tr("&Save"),this);
    /*
    aboutIconAction = new QAction(QIcon("about.png"),tr("About"),this);
    saveIconAction = new QAction(QIcon("save.png"),tr("Save"),this);
    clearIconAction = new QAction(QIcon("Pensseli.png"),tr("Clear"),this);
    exitIconAction = new QAction(QIcon("exit.png"),tr("Exit"),this);
    */
    connect(exitAction,SIGNAL(triggered()),this,SLOT(close()));
    connect(clearAction,SIGNAL(triggered()),this,SLOT(clearTextFields()));
    connect(aboutAction,SIGNAL(triggered()),this,SLOT(showAbout()));
    connect(saveAction,SIGNAL(triggered()),this,SLOT(saveData()));
    /*
    connect(aboutIconAction,SIGNAL(triggered()),this,SLOT(showAbout()));
    connect(clearIconAction,SIGNAL(triggered()),this,SLOT(clearTextFields()));
    connect(exitIconAction,SIGNAL(triggered()),this,SLOT(close()));
    connect(saveIconAction,SIGNAL(triggered()),this,SLOT(saveData()));
    */
}

/**
* Function create menus
*
* @param -
* @return -
*/
void MainWindow::createMenus(){
    //fileMenu = this->menuBar()->addMenu(tr("&File"));
    //aboutMenu = this->menuBar()->addMenu(tr("&Help"));
    menuBar()->addAction(exitAction);
    menuBar()->addAction(clearAction);
    menuBar()->addAction(saveAction);
    menuBar()->addAction(aboutAction);
}

/**
* Function create toolbar
*
* @param -
* @return -
*/
void MainWindow::createToolBars(){
    /*
    toolBar = this->addToolBar(tr("ToolBar"));
    toolBar->addAction(saveIconAction);
    toolBar->addAction(clearIconAction);
    toolBar->addAction(aboutIconAction);
    toolBar->addAction(exitIconAction);
    */
}

/**
* About message
*
* @param -
* @return -
*/
void MainWindow::showAbout(){
    QMessageBox::about(this,tr("About"),tr("Hiking Diary. <a href=www.redneck-wanderers.com>Redneck-Wanderers</a>"));
}

/**
* Function saves data to the text file
*
* @param -
* @return -
*/
bool MainWindow::saveData(){

    //xmlparser->writeXmlData(headerText->text(),date, textContent->toPlainText(),latitudeString.text(),longitudeString.text());

    //return true;

    /*
    QString diaryPath = "/home/user";
    QDir dataDir(diaryPath);
    dataDir.setPath(diaryPath);

    if(!dataDir.exists(diaryPath)){
        qDebug() << "The path is" << dataDir.path();
        dataDir.mkpath("hikingdiary");
    }

    fileNameString = "/home/user/diaryContent.xml";

    QFile file(fileNameString);

    if(!file.open( QIODevice::ReadWrite | QIODevice::Append )){
        QMessageBox::warning(this, tr("Hiking Diary"),
                             tr("Cannot write file Error: %1.\n %2")
                             .arg(file.fileName())
                             .arg(file.errorString()));
        return false;
    }
    QXmlStreamWriter stream( &file );
    stream.setAutoFormatting(true);
    stream.writeStartDocument();

    stream.writeAttribute("version", "1.0");
    stream.writeStartElement("header");
    stream.writeAttribute("header", headerText->text());
    stream.writeStartElement("date");
    stream.writeAttribute("date", strDate);
    stream.writeStartElement("position");
    stream.writeAttribute("latitude", latCoordData->text());
    stream.writeAttribute("longitude",lonCoordData->text());
    //! [write element]

    //stream.writeTextElement("title", "Qt Home");
    stream.writeStartElement("content");
    stream.writeTextElement("content", textContent->toPlainText());

    stream.writeEndElement(); // content
    stream.writeEndElement(); // position
    stream.writeEndElement(); // date
    stream.writeEndElement(); // header

    //! [finish stream]
    stream.writeEndDocument();

    //! [finish stream]
    //! [write output]
    file.close();

    */
    statusBar()->showMessage(tr("File saved"), 2000);

    clearTextFields();
    return true;
}

bool MainWindow::writeXml(){
    return true;
}
