#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QFormLayout>
#include <QGridLayout>
#include <QTextEdit>
#include <QLineEdit>
#include <QTextLine>
#include <QPushButton>
#include <QMenu>
#include <QMenuBar>
#include <QToolBar>
#include <QAction>
#include <QLabel>
#include <QDateTime>
#include <QString>
#include <QMessageBox>
#include <QtXml/QDomDocument>
#include <QtXml/QDomNode>
#include <QFile>
#include <QTextStream>
#include <QTreeView>
#include <QXmlStreamWriter>
#include <QtXml>
#include <QtDebug>
#include <QStatusBar>

#include "maemo5location.h"
#include "xmlparser.h"
#include "diarydatamanager.h"

#define MAX_FIELDS 2
#define MAX_BUTTONS 3
// #define CONTENT_DATA "/usr/share/doc/hikingdiary/diaryContent.xml"


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();
private:
    QGridLayout *mainGridlayout;
    QLabel *dateLabel;
    QDate date;
    QDateTime dtime;
    QString strDate;
    QLineEdit latitudeString;
    QLineEdit longitudeString;
    QString fileNameString;
    QLineEdit *headerText;
    QTextEdit *textContent;
    //QLineEdit* textFields[MAX_FIELDS];
    QLabel *latCoordLabel;
    QLabel *lonCoordLabel;
    //QLabel *accLabel;
    QLineEdit *latCoordData;
    QLineEdit *lonCoordData;
    //QLineEdit *accData;
    QPushButton* buttons[MAX_BUTTONS];
    QPushButton *getCoordButton;
    QVBoxLayout* textLayout;
    QHBoxLayout* coordVLayout;
    QGridLayout *coordGridLayout;
    QHBoxLayout* buttonLayout;
    QMenu* fileMenu;
    QMenu* aboutMenu;
    QToolBar* toolBar;
    QAction* exitAction;
    QAction* aboutAction;
    QAction* clearAction;
    QAction* saveAction;
    QAction* aboutIconAction;
    QAction* saveIconAction;
    QAction* clearIconAction;
    QAction* exitIconAction;

    QDomDocument *diaryDocs;
    QFile file;
    QTextStream out;

    enum BUTTONS
    {
        SAVE,
        CLEAR,
        EXIT
    };
private:
    void createTextLayout();
    void createCoordLayout();
    void createButtons();
    void createMenus();
    void createActions();
    void createToolBars();

    bool writeXml();

private slots:
    void clearTextFields();
    void showAbout();
    bool saveData();
    void getCoordinates();
private:
    Maemo5Location* location;
    diaryDataManager* manager;
    //xmlParser* xmlparser;
};

#endif // MAINWINDOW_H
